@@ -14,25 +14,11 @@ import os
 __all__ = ['ValueBag']
  
 class ValueBag(dict):
-    def __init__(self, d = {}, auto_create = True, empty_string = None):
+    def __init__(self, d = {}):
         super(ValueBag, self).__init__()
         
-        #assert parent == None or isinstance(parent, ValueBag)  
-        #self.__dict__['__parent'] = parent 
-        self.__dict__['__auto_create'] = auto_create
-        self.__dict__['__empty_string'] = empty_string
-        
         self.update(d)
 
-    def __str__(self):
-        if len(self) or self.__dict__['__empty_string'] is None:
-            return super(ValueBag, self).__str__()
-
-        return self.__dict__['__empty_string']
-
-    def __unicode__(self):
-        return str(self)
-        
     def __setattr__(self, name, value):
         if name.startswith('__'):
             self.__dict__[name] = value
@@ -54,10 +40,7 @@ class ValueBag(dict):
                 value = os.path.expanduser(value)
                 value = os.path.expandvars(value)
                 
-        if isinstance(value, ValueBag):
-            #value.__dict__['__parent'] = self
-            pass
-        elif isinstance(value, dict):
+        if isinstance(value, dict):
             value = ValueBag(value)
 
         super(ValueBag, s).__setitem__(name, value)
@@ -74,9 +57,9 @@ class ValueBag(dict):
 
 
         if self.has_key(name):
-            return self.get(name)
+            return super(ValueBag, self).__getitem__(name)
         
-        if not name.startswith('__') and self.__dict__['__auto_create']:
+        if not name.startswith('__'):
             setattr(self, name, {})
         return super(ValueBag, self).__getitem__(name)
     
@@ -97,6 +80,10 @@ class ValueBag(dict):
             for (k, v) in E:
                 self[k] = v
 
+    def get(self, key, default = None):
+        ret = self[key]
+        return ret if ret else default
+
 class _JSONEncoder(json.encoder.JSONEncoder):
     def default(self, o):
         return str(o)
@@ -144,7 +131,19 @@ if __name__ == '__main__':
             obj.newitem2
             self.assertTrue(isinstance(obj.newitem, ValueBag))
             self.assertEqual(2, len(obj))
+
+        def test_recursive(self):
+            obj = ValueBag()
+            obj.a.b.c = 1
+            self.assertEqual(obj.a.b.c, 1)
+            self.assertEqual(obj['a.b.c'], 1)
+            self.assertEqual(obj.get('a.b.c'), 1)
+
+            obj['foo.bar'] = 2
+            self.assertEqual(obj.foo.bar, 2)
+            self.assertEqual(obj['foo.bar'], 2)
+            self.assertEqual(obj.get('foo.bar'), 2)
             
     
-    program.unittest()
+    program.unittest_main()
         
